@@ -60,7 +60,11 @@ $('#ID').click(function() {
     $.post("PROGRAM_TO_RUN", { RUNMODE ts: new Date().getTime()} ); 
     });
 EOD
-    $function =~ s/DEBUG/$.taconite.debug = true;/ if $my->{param}{debug} ;
+    if ( $my->{param}{debug} ) { 
+	$function =~ s!DEBUG!$.taconite.debug = true;! ;
+    } else { 
+	$function =~ s!DEBUG!! ;
+    } 
     $function =~ s/ID/$id/ ; 
     $function =~ s/PROGRAM_TO_RUN/$remoteProgram/ ; 
     $function =~ s/RUNMODE/$runMode/ ; 
